@@ -3,7 +3,7 @@
 #-------------------------------------------------------------------------------
 """Setup and activate a python virtual environment through setup."""
 __author__ = ('Lance Finn Helsten',)
-__version__ = '0.5'
+__version__ = '0.6'
 __copyright__ = """Copyright (C) 2014 Lance Helsten"""
 __docformat__ = "reStructuredText en"
 __license__ = """
@@ -49,10 +49,12 @@ class VirtualEnv(setuptools.Command):
     description = "Setup the venv for this project."
     user_options = [
         ('venv-base=', None, "path to virtual environment directory (default: VENV)"),
+        ('upgrade', 'U', "upgrade the packages"),
     ]
 
     def initialize_options(self):
         self.venv_base = None
+        self.upgrade = False
 
     def finalize_options(self):
         if self.venv_base is None:
@@ -110,11 +112,12 @@ class VirtualEnv(setuptools.Command):
 
 
     def install_package(self, package, env):
-        args = [
-            os.path.join(self.venv_base, 'bin', 'pip'),
-            'install',
-            package
-        ]
+        args = []
+        args.append(os.path.join(self.venv_base, 'bin', 'pip'))
+        args.append('install')
+        if self.upgrade:
+            args.append('--upgrade')
+        args.append(package)
         subprocess.check_call(args, env=env, stdout=sys.stdout, stderr=sys.stderr)
 
 
